class TgcfWatermark:
    id_ = "watermark"

    def __init__(self, data) -> None:
        pass

    def modify(self, message):
        pass
